@@ -1,4 +1,3 @@
-# $Id: Config_file.pm,v 1.8 2004/05/13 19:32:51 epaepa Exp $
 package XMLTV::Config_file;
 use strict;
 use XMLTV::Ask;
@@ -45,9 +44,9 @@ sub filename( $$;$$ ) {
 #
 sub check_no_overwrite( $ ) {
     my $f = shift;
-    if (-e $f) {
-	if (not askBooleanQuestion <<END
-The configuration file $f
+    if (-s $f) {
+	if (not ask_boolean <<END
+A nonempty configuration file $f
 already exists.  There is currently no support for altering an
 existing configuration: you have to reconfigure from scratch.
 
