@@ -1,10 +1,25 @@
-# Add a --version argument to your program, eg
-#
-# use XMLTV::Version '$Id: Version.pm,v 1.1 2003/05/19 19:31:35 epaepa Exp $';
-#
-# Best to put that before other module imports, so that even if they
-# fail --version will still work.
-#
+=head1 NAME
+
+XMLTV::Version - Adds a --version argument to XMLTV grabbers
+
+=head1 DESCRIPTION
+
+Add a --version argument to your program, eg
+
+  use XMLTV::Version '1.2';
+
+If a --version parameter is supplied on the command-line, it will
+be caught already by the "use" statement, a message will be printed
+to STDOUT and the program will exit.
+
+It is best to put the use XMLTV::Version statement before other module
+imports, so that even if they fail --version will still work.
+
+=head1 SEE ALSO
+
+L<XMLTV::Options>
+
+=cut
 
 package XMLTV::Version;
 
@@ -28,12 +43,7 @@ sub import( $$ ) {
     print "could not load XMLTV module, xmltv is not properly installed\n"
       if $@;
     for ($_[1]) {
-	if (m!\$Id: ([^,]+),v (\S+) ([0-9/: -]+)!) {
-	    print "This is $1 version $2, $3\n";
-	}
-	else {
-	    print "This program version $_\n";
-	}
+	print "This program version $_\n";
     }
 
     exit();
