@@ -1,6 +1,5 @@
 #!perl -w
 #
-# $Id: exe_wrap.pl,v 1.83 2009/08/10 05:22:04 rmeden Exp $
 # This is a quick XMLTV shell routing to use with the windows exe
 #
 # A single EXE is needed to allow sharing of modules and dlls of all the
@@ -69,24 +68,12 @@ print STDERR "Timezone is $ENV{TZ}\n" unless $opt_quiet;
 $cmd = shift || "";
 
 # --version (and abbreviations thereof)
-my $VERSION = '0.5.56';
+my $VERSION = '0.6.1';
 if (index('--version', $cmd) == 0 and length $cmd >= 3) {
     print "xmltv $VERSION\n";
     exit;
 }
 
-#
-# some grabbers aren't included
-#
-if ($cmd =~ /^tv_grab_(?:nz|jp)$/) {
-    die <<END
-Sorry, $cmd is not available in this Windows binary release, although
-it is included in xmltv source releases.
-
-END
-  ;
-};
-
 #
 # some programs use a "share" directory
 #
@@ -97,7 +84,7 @@ if ($cmd eq 'tv_grab_na_dd',
     unless (grep(/^--share/i,@ARGV))  # don't add our --share if one supplied
     {
         my $dir = dirname(PerlApp::exe()); # get full program path
-        $dir =~ s!\\!/!g;      # use / not \   
+        $dir =~ s!\\!/!g;      # use / not \
 #       die "EXE path contains spaces.  This is known to cause problems.\nPlease move xmltv.exe to a different directory\n" if $dir =~ / /;
         $dir .= "/share/xmltv";
     	unless (-d $dir )
@@ -127,7 +114,7 @@ if ($cmd eq 'exec')
    exit 1 if length($@);
    exit 0;
 }
-  
+
 #
 # scan through attached files and execute program if found
 #
@@ -167,7 +154,7 @@ print STDERR "Valid commands are:\n";
 @cmds=sort keys %cmds;
 $rows = int($#cmds / 3)+1;
 
-map {$_='' unless defined $_} @cmds[0..($rows*3+2)];    
+map {$_='' unless defined $_} @cmds[0..($rows*3+2)];
 unshift @cmds,undef;
 
 foreach (1..$rows)
